==> org.Dm.eg.db_3.7.0.tar.gz: org.Dm.eg.db/man/org.Dm.egFLYBASEPROT.Rd <==
\name{org.Dm.egFLYBASEPROT}
\alias{org.Dm.egFLYBASEPROT}
\alias{org.Dm.egFLYBASEPROT2EG}
\title{Map FlyBase Protein Acession numbers with Entrez Gene identifiers}  
\description{ 
  org.Dm.egFLYBASE is an R object that contains mappings between 
  Entrez Gene identifiers and FlyBase protein accession numbers.    
}
\details{
  This object is a simple mapping of Entrez Gene identifiers
  \url{https://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene} to Flybase
  protein accession numbers.

  Mappings were based on data provided by: Entrez Gene  
  ftp://ftp.ncbi.nlm.nih.gov/gene/DATA  
  With a date stamp from the source of: 2018-Oct11
}

\seealso{
  \itemize{
    \item \code{\link[AnnotationDbi]{AnnotationDb-class}} for use of
          the \code{select()} interface.
  }
}

\examples{
## select() interface:
## Objects in this package can be accessed using the select() interface
## from the AnnotationDbi package. See ?select for details.

## Bimap interface:
x <- org.Dm.egFLYBASEPROT
# Get the entrez gene IDs that are mapped to a Flybase prot ID
mapped_genes <- mappedkeys(x)
# Convert to a list
xx <- as.list(x[mapped_genes])
if(length(xx) > 0) {
  # Get the FlyBase protein IDs for the first five genes
  xx[1:5]
  # Get the first one
  xx[[1]]
}
#For the reverse map FLYBASEPROT2EG:
# Convert to a list
xx <- as.list(org.Dm.egFLYBASEPROT2EG)
if(length(xx) > 0){
   # Gets the entrez gene IDs for the first five FlyBase protein IDs
   xx[1:5]
   # Get the first one
   xx[[1]]
}
}
\keyword{datasets}

==> org.Dm.eg.db_3.8.2.tar.gz: org.Dm.eg.db/man/org.Dm.egFLYBASEPROT.Rd <==
\name{org.Dm.egFLYBASEPROT}
\alias{org.Dm.egFLYBASEPROT}
\alias{org.Dm.egFLYBASEPROT2EG}
\title{Map FlyBase Protein Acession numbers with Entrez Gene identifiers}  
\description{ 
  org.Dm.egFLYBASE is an R object that contains mappings between 
  Entrez Gene identifiers and FlyBase protein accession numbers.    
}
\details{
  This object is a simple mapping of Entrez Gene identifiers
  \url{https://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene} to Flybase
  protein accession numbers.

  Mappings were based on data provided by: Entrez Gene  
  ftp://ftp.ncbi.nlm.nih.gov/gene/DATA  
  With a date stamp from the source of: 2019-Apr26
}

\seealso{
  \itemize{
    \item \code{\link[AnnotationDbi]{AnnotationDb-class}} for use of
          the \code{select()} interface.
  }
}

\examples{
## select() interface:
## Objects in this package can be accessed using the select() interface
## from the AnnotationDbi package. See ?select for details.

## Bimap interface:
x <- org.Dm.egFLYBASEPROT
# Get the entrez gene IDs that are mapped to a Flybase prot ID
mapped_genes <- mappedkeys(x)
# Convert to a list
xx <- as.list(x[mapped_genes])
if(length(xx) > 0) {
  # Get the FlyBase protein IDs for the first five genes
  xx[1:5]
  # Get the first one
  xx[[1]]
}
#For the reverse map FLYBASEPROT2EG:
# Convert to a list
xx <- as.list(org.Dm.egFLYBASEPROT2EG)
if(length(xx) > 0){
   # Gets the entrez gene IDs for the first five FlyBase protein IDs
   xx[1:5]
   # Get the first one
   xx[[1]]
}
}
\keyword{datasets}
